---
name: Technisches Problem / Python Specific Problem
about: A bug regarding this Python implementation of BO4E but _not_ the BO4E data
  model
title: 'A meaningful Title: FooNotFoundException when Deserializing BO Foo with bar=123'
labels: "bug, Python Specific \U0001F40D"
assignees: ''

---

_Diese Vorlage ist für technische Fragen und Bug Reports. Unklarheiten oder Fehler/fehlende Features im BO4E-Datenmodell bitte in einer Funktionalen Anforderung beschreiben._

**A clear and concise description of what the bug is.**

## Steps To Reproduce
```python
# your example code goes here
```
Please use minimal examples that are stripped down to the core of the problem.

Even better than only code is a failing unittest (f.e. in a fork/PR)

## Expected vs. Actual Behavior
### What you expected

A clear and concise description of what you expected to happen.

### What actually happened
F.e. an error message or an exception; Include a stack trace if possible.

## Additional context

Please state your **Python version**: 3.xx
